@@ -54,6 +54,11 @@ EGLBoolean wlEglFindExtension(const char *extension, const char *extensions);
 #if HAS_MINCORE
 EGLBoolean wlEglPointerIsDereferencable(void *p);
 EGLBoolean wlEglCheckInterfaceType(struct wl_object *obj, const char *ifname);
+#ifndef WL_CHECK_INTERFACE_TYPE
+#define WL_CHECK_INTERFACE_TYPE(obj, ifname)                            \
+    (wlEglCheckInterfaceType((struct wl_object *)(obj), #ifname) ||     \
+     *(void **)(obj) == &ifname)
+#endif
 #endif
 void wlEglSetErrorCallback(WlEglPlatformData *data,
                            EGLint err,
