@@ -91,6 +91,7 @@ handle_create_stream(struct wl_client *client,
     wlStream->width = width;
     wlStream->height = height;
     wlStream->handle = -1;
+    wlStream->yInverted = EGL_FALSE;
 
     memset(&sockAddr, 0, sizeof(sockAddr));
 
@@ -138,6 +139,16 @@ handle_create_stream(struct wl_client *client,
                 mask |= MASK(WL_EGLSTREAM_ATTRIB_INET_PORT);
                 break;
 
+            case WL_EGLSTREAM_ATTRIB_Y_INVERTED:
+                /* Y_INVERTED should only be set once */
+                if (mask & MASK(WL_EGLSTREAM_ATTRIB_Y_INVERTED)) {
+                    err = WL_EGLSTREAM_ERROR_BAD_ATTRIBS;
+                    goto error_create_stream;
+                }
+                wlStream->yInverted = (EGLBoolean)attr[1];
+                mask |= MASK(WL_EGLSTREAM_ATTRIB_Y_INVERTED);
+                break;
+
             default:
                 assert(!"Unknown attribute");
                 break;
@@ -287,7 +298,7 @@ wl_eglstream_display_bind(WlEglPlatformData *data,
         return EGL_FALSE;
     }
 
-    wlStreamDpy = malloc(sizeof(*wlStreamDpy));
+    wlStreamDpy = calloc(1, sizeof(*wlStreamDpy));
     if (!wlStreamDpy) {
         return EGL_FALSE;
     }
